@@ -294,7 +294,7 @@ class ITreeAdapter(EntityAdapter):
             _done = set()
         for child in self.children():
             if child.eid in _done:
-                self.error('loop in %s tree', child.__regid__.lower())
+                self.error('loop in %s tree: %s', child.__regid__.lower(), child)
                 continue
             yield child
             _done.add(child.eid)
@@ -320,7 +320,7 @@ class ITreeAdapter(EntityAdapter):
         entity = adapter.entity
         while entity is not None:
             if entity.eid in path:
-                self.error('loop in %s tree', entity.__regid__.lower())
+                self.error('loop in %s tree: %s', entity.__regid__.lower(), entity)
                 break
             path.append(entity.eid)
             try:
